==> jc-1.4.0.tar.gz: polyglot/visit/InitChecker__24DataFlowItem.h <==
// class polyglot.visit.InitChecker$DataFlowItem

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 146082755586f7f1 polyglot_visit_DataFlow__24Item
// @dep_class 6d694a85ee826b0c polyglot_visit_InitChecker__24DataFlowItem

// header file dependencies
// @dep_header polyglot_visit_DataFlow__24Item

#include "polyglot/visit/DataFlow__24Item.h"

#ifndef _JC_polyglot_visit_InitChecker__24DataFlowItem_H_
#define _JC_polyglot_visit_InitChecker__24DataFlowItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs	_jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs	_jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$refs	_jc_polyglot_visit_InitChecker__24DataFlowItem$refs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs	_jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object	_jc_polyglot_visit_InitChecker__24DataFlowItem$object;

typedef const struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods	_jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtable	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtype	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtype;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24DataFlowItem$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_polyglot_visit_InitChecker__24DataFlowItem$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *, struct _jc_java_lang_Object$object *);
extern jint _jc_polyglot_visit_InitChecker__24DataFlowItem$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_InitChecker__24DataFlowItem$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_InitChecker__24DataFlowItem$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_InitChecker__24DataFlowItem$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_visit_InitChecker__24DataFlowItem$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *, struct _jc_java_lang_Object$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *);
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24Item$vmethods	polyglot_visit_DataFlow__24Item;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods	polyglot_visit_InitChecker__24DataFlowItem;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs {
	struct _jc_object	*initStatus;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$refs {
    _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs	polyglot_visit_InitChecker__24DataFlowItem;
    _jc_polyglot_visit_DataFlow__24Item$sub_refs	polyglot_visit_DataFlow__24Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs	polyglot_visit_DataFlow__24Item;
    _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs	polyglot_visit_InitChecker__24DataFlowItem;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object {
	_jc_polyglot_visit_InitChecker__24DataFlowItem$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24DataFlowItem$vtype _jc_polyglot_visit_InitChecker__24DataFlowItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24DataFlowItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24DataFlowItem$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24DataFlowItem_H_ */

==> jc-1.4.6.tar.gz: polyglot/visit/InitChecker__24DataFlowItem.h <==
// class polyglot.visit.InitChecker$DataFlowItem

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 146082755586f7f1 polyglot_visit_DataFlow__24Item
// @dep_class 6d694a85ee826b0c polyglot_visit_InitChecker__24DataFlowItem

// header file dependencies
// @dep_header polyglot_visit_DataFlow__24Item

#include "polyglot/visit/DataFlow__24Item.h"

#ifndef _JC_polyglot_visit_InitChecker__24DataFlowItem_H_
#define _JC_polyglot_visit_InitChecker__24DataFlowItem_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Map$object;

// Typedefs
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs	_jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs	_jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$refs	_jc_polyglot_visit_InitChecker__24DataFlowItem$refs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs	_jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs;
typedef struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object	_jc_polyglot_visit_InitChecker__24DataFlowItem$object;

typedef const struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods	_jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods;
typedef const struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtable	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtable;
typedef const struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtype	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtype;

// Constructors
extern void _jc_polyglot_visit_InitChecker__24DataFlowItem$method$_init$39bc1e191d75104e(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_visit_InitChecker__24DataFlowItem$method$equals$8a15e0625571c581(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jint _jc_polyglot_visit_InitChecker__24DataFlowItem$method$hashCode$53152098849316df(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_visit_InitChecker__24DataFlowItem$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_visit_InitChecker__24DataFlowItem$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_polyglot_visit_InitChecker__24DataFlowItem$method_info$hashCode$53152098849316df;
extern _jc_method _jc_polyglot_visit_InitChecker__24DataFlowItem$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_visit_DataFlow__24Item$vmethods	polyglot_visit_DataFlow__24Item;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$vmethods	polyglot_visit_InitChecker__24DataFlowItem;
};

// Vtype
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$vtype {
	_jc_type			type;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs {
	struct _jc_object	*initStatus;
};

// Reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$refs {
    _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_refs	polyglot_visit_InitChecker__24DataFlowItem;
    _jc_polyglot_visit_DataFlow__24Item$sub_refs	polyglot_visit_DataFlow__24Item;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_visit_DataFlow__24Item$sub_nonrefs	polyglot_visit_DataFlow__24Item;
    _jc_polyglot_visit_InitChecker__24DataFlowItem$sub_nonrefs	polyglot_visit_InitChecker__24DataFlowItem;
};

// Object instance structure
struct _jc_polyglot_visit_InitChecker__24DataFlowItem$object {
	_jc_polyglot_visit_InitChecker__24DataFlowItem$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$vtype	*vtype;
	_jc_polyglot_visit_InitChecker__24DataFlowItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_visit_InitChecker__24DataFlowItem$vtype _jc_polyglot_visit_InitChecker__24DataFlowItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_visit_InitChecker__24DataFlowItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_visit_InitChecker__24DataFlowItem$class_object;

#endif	/* _JC_polyglot_visit_InitChecker__24DataFlowItem_H_ */
